--- loncom/publisher/lonpubdir.pm 2003/05/16 20:47:08 1.31
+++ loncom/publisher/lonpubdir.pm 2003/06/18 14:58:39 1.34
@@ -1,7 +1,7 @@
# The LearningOnline Network with CAPA
-# (Publication Handler
+# Construction Space Directory Lister
#
-# $Id: lonpubdir.pm,v 1.31 2003/05/16 20:47:08 albertel Exp $
+# $Id: lonpubdir.pm,v 1.34 2003/06/18 14:58:39 www Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -69,13 +69,13 @@ sub handler {
$fn,$r->dir_config('lonDefDomain'));
unless (($uname) && ($udom)) {
$r->log_reason($uname.' at '.$udom.
- ' trying to publish file '.$ENV{'form.filename'}.
+ ' trying to list directory '.$ENV{'form.filename'}.
' ('.$fn.') - not authorized',
$r->filename);
return HTTP_NOT_ACCEPTABLE;
}
# Remove trailing / from direcgtory name.
$fn=~s/\/$//;
@@ -147,7 +147,9 @@ sub getEffectiveUrl {
# Replace the ~username of the URL with /home/username/public_html
# so that we don't have to worry about ~ expansion internally.
#
- $fn=~s/^http\:\/\/[^\/]+\/\~(\w+)/\/home\/$1\/public_html/;
+ $fn=~s/^http\:\/\/[^\/]+\///;
+ $fn=~s/^\///;
+ $fn=~s/\~(\w+)/\/home\/$1\/public_html/;
# Remove trailing / strings (?)
@@ -308,13 +310,20 @@ sub putresource {
$status.='
Retrieve';
}
+ my $editlink='';
+ if ($filename=~/\.(xml|html|htm|xhtml|xhtm)$/) {
+ $editlink=' (Edit)';
+ }
+ if ($filename=~/\.(problem|exam|quiz|assess|survey|form|library)$/) {
+ $editlink=' (EditXML)';
+ }
$r->print('
@@ -69,13 +69,13 @@ sub handler {
return HTTP_NOT_ACCEPTABLE;
}
- # Remove trailing / from direcgtory name.
+ # Remove trailing / from directory name.
$fn=~s/\/$//;